@@ -1184,14 +1184,14 @@ gchar *get_localized_date(time_t time, gboolean years)
 {
     struct tm *tm = NULL;
 
-    gchar *date_format = g_strdup(nl_langinfo(D_FMT));
+    //gchar *date_format = g_strdup(nl_langinfo(D_FMT));
     gchar *df_no_years = NULL;
     gchar **df_split = NULL;
     gchar date_string[TIMESTRLEN + 1];
 
     tm = localtime(&time);
 
-    strftime(date_string, TIMESTRLEN, date_format, tm);
+    strftime(date_string, TIMESTRLEN, dgettext("hildon-libs","wdgt_va_date"), tm);
 
     if (!years) {
         df_split = g_strsplit_set(date_string, " /-.", -1);
@@ -1218,12 +1218,12 @@ gchar *get_localized_date(time_t time, gboolean years)
             df_no_years = g_strdup("");
 
         g_strfreev(df_split);
-        g_free(date_format);
+       // g_free(date_format);
 
         return df_no_years;
     }
 
-    g_free(date_format);
+    //g_free(date_format);
 
     return g_strdup(date_string);
 }
