@@ -134,7 +134,7 @@ static gboolean check_if_autorefresh_needed()
     }
 
 /*NB#103355*/
-    if (rss_updated + autorefresh_interval >= ts) {
+    if (rss_updated + autorefresh_interval >= ts) {		
         return TRUE;
     } else {
         return FALSE;
@@ -151,16 +151,17 @@ static void handle_iap_connected(AppUIData * app_ui_data,
     
     gint iap_action = app_ui_data->iap_action;
     app_ui_data->iap_action = OSSO_IAP_NO_ACTION;
+	   gint type =
+                getNumericConfValue(RSS_SETTINGS_AUTOMATIC_UPDATES_TYPE);
 
     if (iap_action == OSSO_IAP_REFRESH_NO_DIALOG) {
         if (SFM_NORMAL == app_ui_data->search_mode ||
             SFM_CONNECTING == app_ui_data->search_mode) {
-            gint type =
-                getNumericConfValue(RSS_SETTINGS_AUTOMATIC_UPDATES_TYPE);
+         
 
             ULOG_DEBUG("Autoupdate: type=%d, bearer=%s", type, bearer);
 
-            
+			
             if (((type == 0 && 
                     (strncasecmp(bearer, "WLAN", 4) == 0 || 
                      strncasecmp(bearer, "WIMAX", 5) == 0)) ||
@@ -180,6 +181,16 @@ static void handle_iap_connected(AppUIData * app_ui_data,
             SFM_CONNECTING == app_ui_data->search_mode) {
             ULOG_DEBUG("Refresh without dialog");
 
+      	if(app_data->app_ui_data->manual_refresh_selected == FALSE)
+      	{
+      		if(type == 0 && 
+      		        strncasecmp(bearer, "WLAN", 4) != 0 ) // strncasecmp(bearer, "WIMAX", 5) != 0) for future reference.
+      		{
+      		         return;
+      		}		
+      	}
+	   
+	   app_data->app_ui_data->manual_refresh_selected = FALSE; 
             if (app_ui_data->manage_folders_displayed) {
                 GtkWidget *widget = NULL;
                 widget = lookup_widget (app_ui_data->dialog, "mf_deletebtn");
@@ -388,7 +399,6 @@ static void connection_cb(ConIcConnection * connection,
     error = con_ic_connection_event_get_error(event);
     iap_id = con_ic_event_get_iap_id(CON_IC_EVENT(event));
     bearer = con_ic_event_get_bearer_type(CON_IC_EVENT(event));
-
     /* If user removes the IAP while connecting 
      * ConIC can return NULL as bearer. Ignore
      * these connection events.
@@ -437,13 +447,12 @@ gboolean request_iap_connect()
      * rss was started on background, it will terminate before connection
      * builds up, which will leave rss-applet in "refreshing" state */
     just_started_connecting = TRUE;
-
     ULOG_DEBUG("Requesting new connection.... %d",
                app_data->app_ui_data->iap_action);
     if (app_data->app_ui_data->iap_action == OSSO_IAP_NEW_SUBSCRIPTION
         && app_data->app_ui_data->source
         && strncasecmp(app_data->app_ui_data->source, "file://", 7) == 0) {
-        ULOG_DEBUG("Skipping connecting for local file ...");
+        ULOG_DEBUG("Skipping connecting for local file ...");		
         handle_iap_connected(app_data->app_ui_data, "");
         return TRUE;
     }
@@ -451,13 +460,14 @@ gboolean request_iap_connect()
     if (app_data->app_ui_data->iap_action == OSSO_IAP_NEW_SUBSCRIPTION &&
         app_data->app_ui_data->source &&
         strncasecmp(app_data->app_ui_data->source, "obex://", 7) == 0) {
-        ULOG_DEBUG("Skipping connecting for file on gateway...");
+        ULOG_DEBUG("Skipping connecting for file on gateway...");		
         handle_iap_connected(app_data->app_ui_data, "");
         return TRUE;
     }
 #ifdef FORCE_IAP_CONNECT
     g_debug("connection forced\n");
     handle_iap_connected(app_data->app_ui_data, "WLAN");
+   //app_data->app_ui_data->manual_refresh_selected = FALSE;
 #else
     if (iap) {
         switch_progressbar(PROGRESSBAR_CONNECT_MODE);
@@ -515,7 +525,8 @@ gboolean poll_iphb_fd(gpointer data)
 	fd_set fds;
 	struct timeval time_wait;
 	GConfClient* gconf = gconf_client_get_default();
-	int iphb_fd = gconf_client_get_int(gconf, RSS_SETTINGS_IPHB_HANDLE_ID, NULL);
+	//int iphb_fd = gconf_client_get_int(gconf, RSS_SETTINGS_IPHB_HANDLE_ID, NULL);// commented for 160415.
+	int iphb_fd = get_iphb_fd(iphb_data.iphb_handle);
 	time_t cur_time = 0;
 
 	memset(&time_wait, 0, sizeof(struct timeval));
@@ -852,7 +863,7 @@ extern gboolean lifereaStarted;
 gint event_delete(gpointer data)
 {
 	if( (!app_data->app_ui_data->start_alarmdel_on_background) && (!app_data->app_ui_data->start_on_background) ) {
-		close_iphb_handle(iphb_data);
+		close_iphb_handle(&iphb_data);
 		remove_iphb_callback(iphb_data.source_id);
 		iphb_data.source_id = 0;
 	}	
