@@ -65,13 +65,19 @@ static void initialize_app_ui_data()
     app_data->app_ui_data->update_progress_needed = FALSE;		
     app_data->app_ui_data->call_ui_mainwindow_finish_needed = FALSE;
     app_data->app_ui_data->refresh_dialog = NULL;
+    app_data->app_ui_data->unsubscribe_dialog = NULL;
+    app_data->app_ui_data->clear_cache_dialog = NULL;	
+    app_data->app_ui_data->sort_dialog = NULL;
     app_data->app_ui_data->dialog_closed = FALSE;
     app_data->gconf_client = NULL;
+    app_data->app_ui_data->manual_refresh_selected = FALSE;
 }
 
 static void sig_handler(int _sig)
 {
      uint8_t sig = _sig;
+
+   close_all_opened_dialog(app_data);
      /* write to the sigpipe if SIGTERM is caught*/
      write(sigpipe[1], &sig, sizeof(sig));
 }
@@ -168,7 +174,7 @@ int main(int argc, char *argv[])
 
     g_assert(app_data != NULL);
     g_assert(app_data->app_ui_data != NULL);
-
+    app_data->app_ui_data->connected = FALSE; 
     initialize_app_ui_data();
 
     /*Register the SIGTERM handler for state save and clean exit*/
